@@ -4,6 +4,7 @@
 use PDL::IO::Dcm qw/load_dcm_dir parse_dcms/;
 use strict "vars";
 use PDL::NiceSlice;
+use PDL;
 use PDL::IO::Sereal qw/wsereal/;
 use Getopt::Tabular;
 use Data::Dumper;
@@ -25,7 +26,10 @@ sub printStruct {
 				$res.= "$structName->"."[$i]: ()\n" if (@{$struct->[$i]}==0);
 				my $string = printStruct($struct->[$i],$structName."->[$i]",$pre." ");
 				$res.= "$structName->"."[$i]: $string\n" if ($string);
+			} elsif (ref($struct->[$i]) eq "PDL") { # contents of struct is array ref
+				$res.= "$structName->"."[$i]: ".(join (' ',list ($struct->[$i])))."\n";
 			} else { # contents of struct is a scalar, just print it.
+				
 				$res.= "$structName->"."[$i]: $struct->[$i]\n";
 			}
 		}
@@ -37,14 +41,18 @@ sub printStruct {
 			} elsif (ref($struct->{$_}) eq "ARRAY") { # contents of struct is array ref
 				my $string = printStruct($struct->{$_},$structName."->{$_}",$pre." ");
 				$res.= "$structName->"."{$_}: $string\n" if ($string);
+			} elsif (ref($struct->{$_}) eq "PDL") { # contents of struct is array ref
+				$res.= "$structName->"."{$_}: ".(join (' ',list($struct->{$_})))."\n";
 			} else { # contents of struct is a scalar, just print it.
 				$res.= "$structName->"."{$_}: $struct->{$_}\n";
 			}
 		}
 		#return($res);
+	} elsif (ref ($struct) eq 'PDL') {
+		$res.= "$structName: ".(join (' ',list($struct)))."\n";
 	} else {
 		$res.= "$structName: $struct\n";
-	}
+	} 
 #print "------------------\n" unless (defined($pre));
 	return($res);
 }
@@ -101,7 +109,7 @@ for my $pid (keys %$data) {
 		$ni->write_nii($pre."_$pid.nii");
 		open F,">",$pre."_$pid.txt";
 		print F "## Generated using PDL::IO::Dcm\n\n";
-		print F "dimensions ",join ' ',$$data{$pid}->hdr->{Dimensions};
+		print F "dimensions: ",join ' ',(join ' ',@{$$data{$pid}->hdr->{Dimensions}})."\n\n";
 		print F "### ASCCONV BEGIN ###\n";
 		for my $k (sort keys %{$$data{$pid}->hdr->{ascconv}} ) 
 			{print F "$k = ",$$data{$pid}->hdr->{ascconv}->{$k},"\n" }
