@@ -12,7 +12,7 @@ Version 0.9
 
 =cut
 
-our $VERSION = '0.9';
+our $VERSION = '0.9001';
 
 
 =head1 SYNOPSIS
@@ -108,7 +108,7 @@ use Exporter;
 #use PDL::IO::Nifti;
 use strict;
 #use PDL::IO::Sereal;
-use 5.10.0;
+#use 5.10.0;
 
 our @ISA=qw/Exporter/;
 our @EXPORT_OK=qw/read_text_hdr read_dcm parse_dcms load_dcm_dir/;
@@ -187,7 +187,7 @@ sub read_dcm {
 	my $w=unpack('S',substr ($dcm->getValue('Columns','native'),3,2));
 	my $data=$dcm->getValue('PixelData','native');
 	my $datatype= (substr($data,0,2));
-	say "datatype $datatype";
+	#say "datatype $datatype";
 	my $pdl=zeroes(ushort,$w,$h) if ($datatype =~/OW|XX/); 
 	$pdl->make_physical;
 	${$pdl->get_dataref}=substr($data,3);
@@ -248,12 +248,14 @@ sub load_dcm_dir {
 			push @pid,$pid;
 		}
 		$dcms{$pid}={} unless ref $dcms{$pid};
-		say "pos ",$p->hdr->{dicom}->{'0020,0032'}=~s/\\/ /r;
-		say "orientation ",$p->hdr->{dicom}->{'0020,0037'}=~s/\\/ /r;
-		say "Spacing ",$p->hdr->{dicom}->{'0028,0030'}=~s/\\/ /r;
+		#say "pos ",$p->hdr->{dicom}->{'0020,0032'}=~s/\\/ /r;
+		#say "orientation ",$p->hdr->{dicom}->{'0020,0037'}=~s/\\/ /r;
+		#say "Spacing ",$p->hdr->{dicom}->{'0028,0030'}=~s/\\/ /r;
 #say "IceDims ",$p->hdr->{IceDims};
-		say "$n Series $pid IceDims ",$p->hdr->{IceDims};
-		my $iced=pdl(short,[split ('_',$p->hdr->{IceDims}=~s/X/1/er)]); #badvalue(short)/er)]);
+		#say "$n Series $pid IceDims ",$p->hdr->{IceDims};
+		(my $str=$p->hdr->{IceDims})=~s/X/1/e;
+		my @d=split ('_',$str);
+		my $iced=pdl(short,@d); #badvalue(short)/er)]);
 		#say "$file IceDims ",$iced;
 #$iced->badflag(1);
 		$dims{$pid}.=$dims{$pid}*($dims{$pid}>=$iced)+$iced*($iced>$dims{$pid});
@@ -296,7 +298,7 @@ sub parse_dcms {
 		#}
 #my $other=(@stack/$z,$t,$echoes/$ncoils);
 #my $data{$pid}=zeroes(ushort,$x,$y,$z,$echoes,$ncoils,$t,$other);
-		say "Creating piddle $x,$y, $dims";
+		#say "Creating piddle $x,$y, $dims";
 		# dims: coil echo phase set t ? partition? slice? ? slice ? some_id
 		my $order=pdl[6,7,4,1,0,2,3];
 		$data{$pid}=zeroes(ushort,$x,$y,$dims($order));
@@ -306,7 +308,7 @@ sub parse_dcms {
 		for my $key (@key_list) {
 			$data{$pid}->hdr->{dicom}->{$key}=zeroes(list $dims($order));
 			#$data{$pid}->hdr->{dicom}->{$key}.=$ref->hdr->{dicom}->{$key};
-			say "$key ",$data{$pid}->hdr->{dicom}->{$key}->info;
+			#say "$key ",$data{$pid}->hdr->{dicom}->{$key}->info;
 		}
 		$data{$pid}->hdr->{dicom}->{'Image Orientation (Patient)'}=zeroes(6,list $dims($order));
 		$data{$pid}->hdr->{dicom}->{'Image Position (Patient)'}=zeroes(3,list $dims($order));
